import { get } from 'lodash'

export const isHEToManuscript = (state, collectionId) => {
  const currentUserId = get(state, 'currentUser.user.id')
  const collections = get(state, 'collections') || []
  const collection = collections.find(c => c.id === collectionId) || {}
  return get(collection, 'handlingEditor.id') === currentUserId
}

export const canMakeRecommendation = (state, project) => {
  const isHE = isHEToManuscript(state, project.id)
  return isHE && get(project, 'status') === 'reviewCompleted'
}

export const currentUserIs = ({ currentUser: { user } }, role) => {
  const isAdmin = get(user, 'admin')
  const isEic = get(user, 'editorInChief')
  const isHe = get(user, 'handlingEditor')
  switch (role) {
    case 'isHE':
      return isHe
    case 'staff':
      return isAdmin || isEic || isHe
    case 'adminEiC':
      return isAdmin || isEic
    default:
      return false
  }
}

export const canInviteReviewers = ({ currentUser: { user } }, project) => {
  const status = get(project, 'status')
  if (!status || status === 'rejected' || status === 'published') return false

  const handlingEditor = get(project, 'handlingEditor')
  const isAdmin = get(user, 'admin')
  const isEic = get(user, 'editorInChief')
  const isAccepted = get(handlingEditor, 'isAccepted')
  const heId = get(handlingEditor, 'id')
  return isAccepted && (user.id === heId || isAdmin || isEic)
}

export const getUserToken = ({ currentUser }) => get(currentUser, 'user.token')

export const getHERecommendation = (state, collectionId, fragmentId) => {
  const recommendations =
    get(state, `fragments.${fragmentId}.recommendations`) || []
  const collection = get(state, 'collections').find(c => c.id === collectionId)
  const heId = get(collection, `handlingEditor.id`)

  return (
    recommendations.find(
      ({ userId, recommendationType }) =>
        recommendationType === 'editorRecommendation' && userId === heId,
    ) || {}
  )
}

const cantMakeDecisionStatuses = ['rejected', 'published', 'draft']
export const canMakeDecision = (state, collection) => {
  const status = get(collection, 'status')

  if (!status || cantMakeDecisionStatuses.includes(status)) return false

  const isEIC = currentUserIs(state, 'adminEiC')
  return isEIC && status
}

export const canSeeReviewersReports = (state, collectionId) => {
  const isHE = isHEToManuscript(state, collectionId)
  const isEiC = currentUserIs(state, 'adminEiC')
  return isHE || isEiC
}

export const canMakeRevision = (state, collection, fragment) => {
  const currentUserId = get(state, 'currentUser.user.id')
  return (
    get(fragment, 'revision') &&
    collection.status === 'revisionRequested' &&
    fragment.owners.map(o => o.id).includes(currentUserId)
  )
}

export const currentUserIsAuthor = (state, id) => {
  const permissions = getUserPermissions(state) || []

  return permissions
    .filter(f => f.role === 'author')
    .map(p => p.objectId)
    .includes(id)
}

export const getUserPermissions = ({ currentUser }) =>
  get(currentUser, 'user.teams').map(t => ({
    objectId: t.object.id,
    objectType: t.object.type,
    role: t.teamType.permissions,
  }))

export const userNotConfirmed = ({ currentUser }) =>
  get(currentUser, 'isAuthenticated') &&
  !currentUserIs({ currentUser }, 'staff') &&
  !get(currentUser, 'user.isConfirmed')
