const { heTeamID, revTeamID, authorTeamID } = require('./teamIDs')
const {
  handlingEditor,
  user,
  admin,
  author,
  reviewer,
  answerReviewer,
  submittingAuthor,
  recReviewer,
  answerHE,
  inactiveReviewer,
  inactiveUser,
} = require('./userData')
const Chance = require('chance')

const chance = new Chance()
const users = {
  admin: {
    type: 'user',
    username: 'admin',
    email: admin.email,
    firstName: admin.firstName,
    lastName: admin.lastName,
    password: 'test',
    admin: true,
    id: admin.id,
    isActive: true,
  },
  editorInChief: {
    type: 'user',
    username: chance.word(),
    email: chance.email(),
    password: 'password',
    admin: false,
    id: chance.guid(),
    firstName: chance.first(),
    lastName: chance.last(),
    affiliation: chance.company(),
    title: 'Mr',
    save: jest.fn(() => users.editorInChief),
    isConfirmed: false,
    editorInChief: true,
    isActive: true,
  },
  handlingEditor: {
    type: 'user',
    username: chance.word(),
    email: handlingEditor.email,
    password: 'password',
    admin: false,
    id: handlingEditor.id,
    firstName: handlingEditor.firstName,
    lastName: handlingEditor.lastName,
    teams: [heTeamID],
    save: jest.fn(() => users.handlingEditor),
    editorInChief: false,
    handlingEditor: true,
    title: 'Mr',
    isActive: true,
  },
  answerHE: {
    type: 'user',
    username: chance.word(),
    email: answerHE.email,
    password: 'password',
    admin: false,
    id: answerHE.id,
    firstName: answerHE.firstName,
    lastName: answerHE.lastName,
    teams: [heTeamID],
    save: jest.fn(() => users.answerHE),
    editorInChief: false,
    handlingEditor: true,
    title: 'Mr',
    isActive: true,
  },
  user: {
    type: 'user',
    username: chance.word(),
    email: user.email,
    password: 'password',
    admin: false,
    id: user.id,
    passwordResetToken: chance.hash(),
    firstName: user.firstName,
    lastName: user.lastName,
    affiliation: chance.company(),
    title: 'Mr',
    save: jest.fn(function save() {
      return this
    }),
    isConfirmed: false,
    updateProperties: jest.fn(() => users.user),
    teams: [],
    confirmationToken: chance.hash(),
    validPassword: jest.fn(function validPassword(password) {
      return this.password === password
    }),
    token: chance.hash(),
    isActive: true,
  },
  author: {
    type: 'user',
    username: chance.word(),
    email: author.email,
    password: 'password',
    admin: false,
    id: author.id,
    firstName: author.firstName,
    lastName: author.lastName,
    affiliation: chance.company(),
    title: 'Mr',
    save: jest.fn(() => users.author),
    isConfirmed: true,
    passwordResetToken: chance.hash(),
    passwordResetTimestamp: Date.now(),
    teams: [authorTeamID],
    confirmationToken: chance.hash(),
    isActive: true,
  },
  reviewer: {
    type: 'user',
    username: chance.word(),
    email: reviewer.email,
    password: 'password',
    admin: false,
    id: reviewer.id,
    firstName: reviewer.firstName,
    lastName: reviewer.lastName,
    affiliation: chance.company(),
    title: 'Mr',
    save: jest.fn(() => users.reviewer),
    isConfirmed: true,
    teams: [revTeamID],
    invitationToken: 'inv-token-123',
    isActive: true,
  },
  answerReviewer: {
    type: 'user',
    username: chance.word(),
    email: answerReviewer.email,
    password: 'password',
    admin: false,
    id: answerReviewer.id,
    firstName: answerReviewer.firstName,
    lastName: answerReviewer.lastName,
    affiliation: chance.company(),
    title: 'Dr',
    save: jest.fn(() => users.answerReviewer),
    isConfirmed: true,
    teams: [revTeamID],
    invitationToken: 'inv-token-123',
    isActive: true,
  },
  submittingAuthor: {
    type: 'user',
    username: 'sauthor',
    email: submittingAuthor.email,
    password: 'password',
    admin: false,
    id: submittingAuthor.id,
    passwordResetToken: chance.hash(),
    firstName: submittingAuthor.firstName,
    lastName: submittingAuthor.lastName,
    affiliation: chance.company(),
    title: 'Mr',
    save: jest.fn(() => users.submittingAuthor),
    isConfirmed: false,
    isActive: true,
  },
  recReviewer: {
    type: 'user',
    username: chance.word(),
    email: recReviewer.email,
    password: 'password',
    admin: false,
    id: recReviewer.id,
    firstName: recReviewer.firstName,
    lastName: recReviewer.lastName,
    affiliation: chance.company(),
    title: 'Mr',
    save: jest.fn(() => users.recReviewer),
    isConfirmed: true,
    teams: [revTeamID],
    isActive: true,
  },
  inactiveReviewer: {
    type: 'user',
    username: chance.word(),
    email: inactiveReviewer.email,
    password: 'password',
    admin: false,
    id: inactiveReviewer.id,
    firstName: inactiveReviewer.firstName,
    lastName: inactiveReviewer.lastName,
    affiliation: chance.company(),
    title: 'Dr',
    save: jest.fn(() => users.inactiveReviewer),
    isConfirmed: true,
    teams: [revTeamID],
    isActive: false,
  },
  inactiveUser: {
    type: 'user',
    username: chance.word(),
    email: inactiveUser.email,
    password: 'password',
    admin: false,
    id: inactiveUser.id,
    passwordResetToken: chance.hash(),
    firstName: inactiveUser.firstName,
    lastName: inactiveUser.lastName,
    affiliation: chance.company(),
    title: 'Mr',
    save: jest.fn(function save() {
      return this
    }),
    isConfirmed: false,
    updateProperties: jest.fn(() => users.inactiveUser),
    teams: [],
    confirmationToken: chance.hash(),
    validPassword: jest.fn(function validPassword(password) {
      return this.password === password
    }),
    token: chance.hash(),
    isActive: false,
  },
}

module.exports = users
