import React from 'react'
import { compose } from 'recompose'
import { Icon } from '@pubsweet/ui'
import { connect } from 'react-redux'
import styled from 'styled-components'
import { th } from '@pubsweet/ui-toolkit'
import { withRouter } from 'react-router-dom'
import ZipFiles from 'pubsweet-components-faraday/src/components/Files/ZipFiles'
import {
  Decision,
  Recommendation,
} from 'pubsweet-components-faraday/src/components'

import { createRevision } from 'pubsweet-component-wizard/src/redux/conversion'

import {
  canMakeDecision,
  canMakeRecommendation,
} from 'pubsweet-component-faraday-selectors/src'

const SideBarActions = ({
  project,
  version,
  createRevision,
  canMakeDecision,
  canMakeRecommendation,
}) => (
  <Root>
    {canMakeDecision && (
      <Decision
        collectionId={project.id}
        fragmentId={version.id}
        modalKey={`decide-${version.id}`}
      />
    )}

    {canMakeRecommendation && (
      <Recommendation
        collectionId={project.id}
        fragmentId={version.id}
        modalKey={`recommend-${version.id}`}
      />
    )}
    <ZipFiles
      archiveName={`ID-${project.customId}`}
      collectionId={project.id}
      fragmentId={version.id}
    >
      <ClickableIcon>
        <Icon>download</Icon>
      </ClickableIcon>
    </ZipFiles>
  </Root>
)

export default compose(
  withRouter,
  connect(
    (state, { project, version }) => ({
      canMakeDecision: canMakeDecision(state, project),
      canMakeRecommendation: canMakeRecommendation(state, project),
    }),
    (dispatch, { project, version, history }) => ({
      createRevision: () => dispatch(createRevision(project, version, history)),
    }),
  ),
)(SideBarActions)

// #region styled-components
const Root = styled.div`
  border-bottom: ${th('borderDefault')};
  display: flex;
  justify-content: flex-end;
  padding: ${th('subGridUnit')};
`

const ClickableIcon = styled.div`
  margin: 0 ${th('subGridUnit')};
  &:hover {
    opacity: 0.7;
  }
`
// #endregion
