const bodyParser = require('body-parser')
const orcidRoutes = require('./routes/users/linkOrcid')

const Users = app => {
  app.use(bodyParser.json())
  const authBearer = app.locals.passport.authenticate('bearer', {
    session: false,
  })
  /**
   * @api {post} /api/users/reset-password Reset password
   * @apiGroup Users
   * @apiParamExample {json} Body
   *    {
   *      "email": "email@example.com",
   *      "token": "123123123",
   *      "password": "password",
   *      "firstName": "John",
   *      "lastName": "Smith",
   *      "affiliation": "UCLA",
   *      "title": "Mr"
   *    }
   * @apiSuccessExample {json} Success
   *    HTTP/1.1 200 OK
   *    {
   *      "id": "a6184463-b17a-42f8-b02b-ae1d755cdc6b",
   *      "type": "user",
   *      "admin": false,
   *      "email": "email@example.com",
   *      "teams": [],
   *      "username": "email@example.com",
   *      "fragments": [],
   *      "collections": [],
   *      "isConfirmed": true,
   *      "editorInChief": false,
   *      "handlingEditor": false
   *    }
   * @apiErrorExample {json} Reset password errors
   *    HTTP/1.1 400 Bad Request
   *    HTTP/1.1 404 Not Found
   */
  app.post(
    '/api/users/reset-password',
    require('./routes/users/resetPassword')(app.locals.models),
  )
  /**
   * @api {post} /api/users/confirm Confirm user
   * @apiGroup Users
   * @apiParamExample {json} Body
   *    {
   *      "userId": "valid-user-id",
   *      "confirmationToken": "12312321"
   *    }
   * @apiSuccessExample {json} Success
   *    HTTP/1.1 200 OK
   *    {
   *      "id": "a6184463-b17a-42f8-b02b-ae1d755cdc6b",
   *      "type": "user",
   *      "admin": false,
   *      "email": "email@example.com",
   *      "teams": [],
   *      "username": "email@example.com",
   *      "fragments": [],
   *      "collections": [],
   *      "isConfirmed": true,
   *      "editorInChief": false,
   *      "handlingEditor": false
   *    }
   * @apiErrorExample {json} Forgot Password errors
   *    HTTP/1.1 400 Bad Request
   *    HTTP/1.1 404 Not Found
   */
  app.post(
    '/api/users/confirm',
    require('./routes/users/confirm')(app.locals.models),
  )
  /**
   * @api {post} /api/users/forgot-password Forgot password
   * @apiGroup Users
   * @apiParamExample {json} Body
   *    {
   *      "email": "email@example.com",
   *    }
   * @apiSuccessExample {json} Success
   *    HTTP/1.1 200 OK
   *    {
   *      "message": "A password reset email has been sent to email@example.com"
   *    }
   * @apiErrorExample {json} Forgot Password errors
   *    HTTP/1.1 400 Bad Request
   */
  app.post(
    '/api/users/forgot-password',
    require('./routes/users/forgotPassword')(app.locals.models),
  )
  /**
   * @api {post} /api/users/change-password Change password
   * @apiGroup Users
   * @apiParamExample {json} Body
   *    {
   *      "password": "currentPassword",
   *      "newPassword": "newPassword",
   *    }
   * @apiSuccessExample {json} Success
   *    HTTP/1.1 200 OK
   *    {
   *      "id": "a6184463-b17a-42f8-b02b-ae1d755cdc6b",
   *      "type": "user",
   *      "admin": false,
   *      "email": "email@example.com",
   *      "teams": [],
   *      "username": "email@example.com",
   *      "fragments": [],
   *      "collections": [],
   *      "isConfirmed": true,
   *      "editorInChief": false,
   *      "handlingEditor": false
   *    }
   * @apiErrorExample {json} Reset password errors
   *    HTTP/1.1 400 Bad Request
   *    HTTP/1.1 404 Not Found
   */
  app.post(
    '/api/users/change-password',
    authBearer,
    require('./routes/users/changePassword')(app.locals.models),
  )

  // register ORCID authentication strategy
  orcidRoutes(app)
}

module.exports = Users
